@@ -12,9 +12,8 @@ sub_db_identifier <- function(e, conn, fields) {
 
 translate_sql_ <- function(dots, con, vars_group = NULL, vars_order = NULL,
                            vars_frame = NULL, window = TRUE, context = list()) {
-  stopifnot(is.list(dots) || is.null(dots))
-
   dots <- lapply(dots, rlang::as_quosure, env = emptyenv())
+  con <- dbi_connection(con)
 
   dbplyr::translate_sql_(dots = dots, con = con, vars_group = vars_group,
                          vars_order = vars_order, vars_frame = vars_frame,
